@@ -5,8 +5,7 @@
  *
  * Authored By Matthew Allum  <mallum@openedhand.com>
  *
- * Copyright (C) 2006, 2007, 2008 OpenedHand Ltd
- * Copyright (C) 2009, 2010 Intel Corp
+ * Copyright (C) 2006 OpenedHand
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -31,13 +30,13 @@
 
 /* clutter-actor.h */
 
+#include <glib-object.h>
 #include <pango/pango.h>
-#include <atk/atk.h>
-
-#include <cogl/cogl.h>
 
+#include <clutter/clutter-color.h>
 #include <clutter/clutter-types.h>
 #include <clutter/clutter-event.h>
+#include <clutter/clutter-shader.h>
 
 G_BEGIN_DECLS
 
@@ -94,26 +93,21 @@ typedef void (*ClutterCallback) (ClutterActor *actor,
 
 /**
  * ClutterActorFlags:
- * @CLUTTER_ACTOR_MAPPED: the actor will be painted (is visible, and inside
- *   a toplevel, and all parents visible)
+ * @CLUTTER_ACTOR_MAPPED: the actor will be painted (is visible, and inside a toplevel, and all parents visible)
  * @CLUTTER_ACTOR_REALIZED: the resources associated to the actor have been
  *   allocated
  * @CLUTTER_ACTOR_REACTIVE: the actor 'reacts' to mouse events emmitting event
  *   signals
  * @CLUTTER_ACTOR_VISIBLE: the actor has been shown by the application program
- * @CLUTTER_ACTOR_NO_LAYOUT: the actor provides an explicit layout management
- *   policy for its children; this flag will prevent Clutter from automatic
- *   queueing of relayout and will defer all layouting to the actor itself
  *
  * Flags used to signal the state of an actor.
  */
 typedef enum
 {
-  CLUTTER_ACTOR_MAPPED    = 1 << 1,
-  CLUTTER_ACTOR_REALIZED  = 1 << 2,
-  CLUTTER_ACTOR_REACTIVE  = 1 << 3,
-  CLUTTER_ACTOR_VISIBLE   = 1 << 4,
-  CLUTTER_ACTOR_NO_LAYOUT = 1 << 5
+  CLUTTER_ACTOR_MAPPED   = 1 << 1,
+  CLUTTER_ACTOR_REALIZED = 1 << 2,
+  CLUTTER_ACTOR_REACTIVE = 1 << 3,
+  CLUTTER_ACTOR_VISIBLE  = 1 << 4
 } ClutterActorFlags;
 
 /**
@@ -173,11 +167,9 @@ struct _ClutterActor
  * @unrealize: virtual function, used to deallocate resources allocated
  *   in ::realize; it should chain up to the parent's implementation
  * @map: virtual function for containers and composite actors, to
- *   map their children; it must chain up to the parent's implementation.
- *   Overriding this function is optional.
+ *   map their children; it must chain up to the parent's implementation
  * @unmap: virtual function for containers and composite actors, to
- *   unmap their children; it must chain up to the parent's implementation.
- *   Overriding this function is optional.
+ *   unmap their children; it must chain up to the parent's implementation
  * @paint: virtual function, used to paint the actor
  * @get_preferred_width: virtual function, used when querying the minimum
  *   and natural widths of an actor for a given height; it is used by
@@ -208,13 +200,9 @@ struct _ClutterActor
  * @enter_event: signal class closure for #ClutterActor::enter-event
  * @leave_event: signal class closure for #ClutterActor::leave-event
  * @captured_event: signal class closure for #ClutterActor::captured-event
- * @key_focus_in: signal class closure for #ClutterActor::key-focus-in
- * @key_focus_out: signal class closure for #ClutterActor::key-focus-out
+ * @key_focus_in: signal class closure for #ClutterActor::focus-in
+ * @key_focus_out: signal class closure for #ClutterActor::focus-out
  * @queue_relayout: class handler for #ClutterActor::queue-relayout
- * @get_accessible: virtual function, returns the accessible object that
- *   describes the actor to an assistive technology.
- * @get_paint_volume: virtual function, for sub-classes to define their
- *   #ClutterPaintVolume
  *
  * Base class for actors.
  */
@@ -224,19 +212,19 @@ struct _ClutterActorClass
   GInitiallyUnownedClass parent_class;
 
   /*< public >*/
-  void (* show)                 (ClutterActor          *self);
-  void (* show_all)             (ClutterActor          *self);
-  void (* hide)                 (ClutterActor          *self);
-  void (* hide_all)             (ClutterActor          *self);
-  void (* realize)              (ClutterActor          *self);
-  void (* unrealize)            (ClutterActor          *self);
-  void (* map)                  (ClutterActor          *self);
-  void (* unmap)                (ClutterActor          *self);
-  void (* paint)                (ClutterActor          *self);
+  void (* show)                 (ClutterActor          *actor);
+  void (* show_all)             (ClutterActor          *actor);
+  void (* hide)                 (ClutterActor          *actor);
+  void (* hide_all)             (ClutterActor          *actor);
+  void (* realize)              (ClutterActor          *actor);
+  void (* unrealize)            (ClutterActor          *actor);
+  void (* map)                  (ClutterActor          *actor);
+  void (* unmap)                (ClutterActor          *actor);
+  void (* paint)                (ClutterActor          *actor);
   void (* parent_set)           (ClutterActor          *actor,
                                  ClutterActor          *old_parent);
 
-  void (* destroy)              (ClutterActor          *self);
+  void (* destroy)              (ClutterActor          *actor);
   void (* pick)                 (ClutterActor          *actor,
                                  const ClutterColor    *color);
 
@@ -244,15 +232,15 @@ struct _ClutterActorClass
                                  ClutterActor          *leaf_that_queued);
 
   /* size negotiation */
-  void (* get_preferred_width)  (ClutterActor           *self,
+  void (* get_preferred_width)  (ClutterActor           *actor,
                                  gfloat                  for_height,
                                  gfloat                 *min_width_p,
                                  gfloat                 *natural_width_p);
-  void (* get_preferred_height) (ClutterActor           *self,
+  void (* get_preferred_height) (ClutterActor           *actor,
                                  gfloat                  for_width,
                                  gfloat                 *min_height_p,
                                  gfloat                 *natural_height_p);
-  void (* allocate)             (ClutterActor           *self,
+  void (* allocate)             (ClutterActor           *actor,
                                  const ClutterActorBox  *box,
                                  ClutterAllocationFlags  flags);
 
@@ -284,17 +272,11 @@ struct _ClutterActorClass
   void     (* key_focus_in)         (ClutterActor         *actor);
   void     (* key_focus_out)        (ClutterActor         *actor);
 
-  void     (* queue_relayout)       (ClutterActor         *self);
-
-  /* accessibility support */
-  AtkObject * (* get_accessible)    (ClutterActor         *self);
-
-  gboolean    (* get_paint_volume)  (ClutterActor         *actor,
-                                     ClutterPaintVolume   *volume);
+  void     (* queue_relayout)       (ClutterActor         *actor);
 
   /*< private >*/
   /* padding for future expansion */
-  gpointer _padding_dummy[29];
+  gpointer _padding_dummy[31];
 };
 
 GType                 clutter_actor_get_type                  (void) G_GNUC_CONST;
@@ -315,7 +297,6 @@ void                  clutter_actor_map                       (ClutterActor
 void                  clutter_actor_unmap                     (ClutterActor          *self);
 void                  clutter_actor_paint                     (ClutterActor          *self);
 void                  clutter_actor_queue_redraw              (ClutterActor          *self);
-
 void                  clutter_actor_queue_relayout            (ClutterActor          *self);
 void                  clutter_actor_destroy                   (ClutterActor          *self);
 
@@ -347,13 +328,6 @@ void                  clutter_actor_allocate_available_size   (ClutterActor
                                                                gfloat                 available_width,
                                                                gfloat                 available_height,
                                                                ClutterAllocationFlags flags);
-void                  clutter_actor_allocate_align_fill       (ClutterActor          *self,
-                                                               const ClutterActorBox *box,
-                                                               gdouble                x_align,
-                                                               gdouble                y_align,
-                                                               gboolean               x_fill,
-                                                               gboolean               y_fill,
-                                                               ClutterAllocationFlags flags);
 void                  clutter_actor_get_allocation_box        (ClutterActor          *self,
                                                                ClutterActorBox       *box);
 void                  clutter_actor_get_allocation_geometry   (ClutterActor          *self,
@@ -441,9 +415,6 @@ void                  clutter_actor_get_clip                  (ClutterActor
                                                                gfloat                *yoff,
                                                                gfloat                *width,
                                                                gfloat                *height);
-void                  clutter_actor_set_clip_to_allocation    (ClutterActor          *self,
-                                                               gboolean               clip_set);
-gboolean              clutter_actor_get_clip_to_allocation    (ClutterActor          *self);
 
 void                  clutter_actor_set_parent                (ClutterActor          *self,
                                                                ClutterActor          *parent);
@@ -451,8 +422,6 @@ ClutterActor *        clutter_actor_get_parent                (ClutterActor
 void                  clutter_actor_reparent                  (ClutterActor          *self,
                                                                ClutterActor          *new_parent);
 void                  clutter_actor_unparent                  (ClutterActor          *self);
-gboolean              clutter_actor_contains                  (ClutterActor          *self,
-							       ClutterActor          *descendant);
 ClutterActor*         clutter_actor_get_stage                 (ClutterActor          *actor);
 
 void                  clutter_actor_raise                     (ClutterActor          *self,
@@ -497,7 +466,7 @@ gboolean              clutter_actor_event                     (ClutterActor
                                                                ClutterEvent          *event,
                                                                gboolean               capture);
 
-ClutterActor *        clutter_get_actor_by_gid                (guint32                id_);
+ClutterActor *        clutter_get_actor_by_gid                (guint32                id);
 
 gboolean              clutter_actor_set_shader                (ClutterActor          *self,
                                                                ClutterShader         *shader);
@@ -558,27 +527,6 @@ void clutter_actor_get_transformation_matrix          (ClutterActor        *self
                                                        CoglMatrix          *matrix);
 
 gboolean clutter_actor_is_in_clone_paint              (ClutterActor        *self);
-gboolean clutter_actor_has_pointer                    (ClutterActor        *self);
-
-void                 clutter_actor_set_text_direction (ClutterActor         *self,
-                                                       ClutterTextDirection  text_dir);
-ClutterTextDirection clutter_actor_get_text_direction (ClutterActor         *self);
-
-void                 clutter_actor_push_internal      (ClutterActor         *self);
-void                 clutter_actor_pop_internal       (ClutterActor         *self);
-
-gboolean             clutter_actor_has_allocation     (ClutterActor         *self);
-
-AtkObject *          clutter_actor_get_accessible     (ClutterActor         *self);
-
-gboolean             clutter_actor_has_key_focus      (ClutterActor         *self);
-
-const ClutterPaintVolume  *clutter_actor_get_paint_volume             (ClutterActor         *self);
-const ClutterPaintVolume  *clutter_actor_get_transformed_paint_volume (ClutterActor *self,
-                                                                       ClutterActor *relative_to_ancestor);
-
-gboolean             clutter_actor_get_paint_box      (ClutterActor         *self,
-                                                       ClutterActorBox      *box);
 
 G_END_DECLS
 
