@@ -63,6 +63,7 @@ struct _ClutterBackendPrivate
   gdouble resolution;
 
   gfloat units_per_em;
+  gint32 units_serial;
 
   cairo_font_options_t *font_options;
 
@@ -160,7 +161,10 @@ get_units_per_em (ClutterBackend       *backend,
 static void
 clutter_backend_real_resolution_changed (ClutterBackend *backend)
 {
-  backend->priv->units_per_em = get_units_per_em (backend, NULL);
+  ClutterBackendPrivate *priv = backend->priv;
+
+  priv->units_per_em = get_units_per_em (backend, NULL);
+  priv->units_serial += 1;
 
   CLUTTER_NOTE (BACKEND, "Units per em: %.2f", backend->priv->units_per_em);
 }
@@ -168,7 +172,10 @@ clutter_backend_real_resolution_changed (ClutterBackend *backend)
 static void
 clutter_backend_real_font_changed (ClutterBackend *backend)
 {
-  backend->priv->units_per_em = get_units_per_em (backend, NULL);
+  ClutterBackendPrivate *priv = backend->priv;
+
+  priv->units_per_em = get_units_per_em (backend, NULL);
+  priv->units_serial += 1;
 
   CLUTTER_NOTE (BACKEND, "Units per em: %.2f", backend->priv->units_per_em);
 }
@@ -212,7 +219,9 @@ clutter_backend_init (ClutterBackend *backend)
   priv = backend->priv = CLUTTER_BACKEND_GET_PRIVATE (backend);
 
   priv->resolution = -1.0;
+
   priv->units_per_em = -1.0;
+  priv->units_serial = 1;
 }
 
 void
@@ -258,14 +267,14 @@ _clutter_backend_post_parse (ClutterBackend  *backend,
   return TRUE;
 }
 
-ClutterActor *
+ClutterStageWindow *
 _clutter_backend_create_stage (ClutterBackend  *backend,
                                ClutterStage    *wrapper,
                                GError         **error)
 {
   ClutterBackendClass *klass;
   ClutterStageManager *stage_manager;
-  ClutterActor        *stage = NULL;
+  ClutterStageWindow *stage_window;
 
   g_return_val_if_fail (CLUTTER_IS_BACKEND (backend), FALSE);
   g_return_val_if_fail (CLUTTER_IS_STAGE (wrapper), FALSE);
@@ -274,16 +283,16 @@ _clutter_backend_create_stage (ClutterBackend  *backend,
 
   klass = CLUTTER_BACKEND_GET_CLASS (backend);
   if (klass->create_stage)
-    stage = klass->create_stage (backend, wrapper, error);
+    stage_window = klass->create_stage (backend, wrapper, error);
 
-  if (!stage)
+  if (!stage_window)
     return NULL;
 
-  g_assert (CLUTTER_IS_STAGE_WINDOW (stage));
-  _clutter_stage_set_window (wrapper, CLUTTER_STAGE_WINDOW (stage));
+  g_assert (CLUTTER_IS_STAGE_WINDOW (stage_window));
+  _clutter_stage_set_window (wrapper, stage_window);
   _clutter_stage_manager_add_stage (stage_manager, wrapper);
 
-  return stage;
+  return stage_window;
 }
 
 void
@@ -299,7 +308,6 @@ _clutter_backend_redraw (ClutterBackend *backend,
 
 gboolean
 _clutter_backend_create_context (ClutterBackend  *backend,
-                                 gboolean         is_offscreen,
                                  GError         **error)
 {
   ClutterBackendClass *klass;
@@ -308,7 +316,7 @@ _clutter_backend_create_context (ClutterBackend  *backend,
 
   klass = CLUTTER_BACKEND_GET_CLASS (backend);
   if (klass->create_context)
-    return klass->create_context (backend, is_offscreen, error);
+    return klass->create_context (backend, error);
 
   return TRUE;
 }
@@ -721,3 +729,11 @@ clutter_backend_get_font_name (ClutterBackend *backend)
 
   return priv->font_name;
 }
+
+gint32
+_clutter_backend_get_units_serial (ClutterBackend *backend)
+{
+  g_return_val_if_fail (CLUTTER_IS_BACKEND (backend), 0);
+
+  return backend->priv->units_serial;
+}
