@@ -39,16 +39,6 @@
  *   alignment policies.</simpara></listitem>
  * </itemizedlist>
  *
- * <figure id="bin-layout">
- *   <title>Bin layout</title>
- *   <para>The image shows a #ClutterBinLayout with three layers:
- *   a background #ClutterCairoTexture, set to fill on both the X
- *   and Y axis; a #ClutterTexture, set to center on both the X and
- *   Y axis; and a #ClutterRectangle, set to %CLUTTER_BIN_ALIGNMENT_END
- *   on both the X and Y axis.</para>
- *   <graphic fileref="bin-layout.png" format="PNG"/>
- * </figure>
- *
  * <example id="example-clutter-bin-layout">
  *  <title>How to pack actors inside a BinLayout</title>
  *  <para>The following code shows how to build a composite actor with
@@ -459,7 +449,6 @@ clutter_bin_layout_allocate (ClutterLayoutManager   *manager,
           continue;
         }
 
-      child_width = child_height = 0;
       request = clutter_actor_get_request_mode (child);
       if (request == CLUTTER_REQUEST_HEIGHT_FOR_WIDTH)
         {
@@ -530,12 +519,6 @@ clutter_bin_layout_allocate (ClutterLayoutManager   *manager,
   g_list_free (children);
 }
 
-static GType
-clutter_bin_layout_get_child_meta_type (ClutterLayoutManager *manager)
-{
-  return CLUTTER_TYPE_BIN_LAYER;
-}
-
 static ClutterLayoutMeta *
 clutter_bin_layout_create_child_meta (ClutterLayoutManager *manager,
                                       ClutterContainer     *container,
@@ -669,8 +652,6 @@ clutter_bin_layout_class_init (ClutterBinLayoutClass *klass)
     clutter_bin_layout_allocate;
   layout_class->create_child_meta =
     clutter_bin_layout_create_child_meta;
-  layout_class->get_child_meta_type =
-    clutter_bin_layout_get_child_meta_type;
   layout_class->set_container =
     clutter_bin_layout_set_container;
 }
