@@ -188,13 +188,12 @@ GType         _clutter_backend_impl_get_type  (void);
 
 void          _clutter_backend_redraw         (ClutterBackend  *backend,
                                                ClutterStage    *stage);
-ClutterActor *_clutter_backend_create_stage   (ClutterBackend  *backend,
+ClutterStageWindow *_clutter_backend_create_stage   (ClutterBackend  *backend,
                                                ClutterStage    *wrapper,
                                                GError         **error);
 void          _clutter_backend_ensure_context (ClutterBackend  *backend,
                                                ClutterStage    *stage);
 gboolean      _clutter_backend_create_context (ClutterBackend  *backend,
-                                               gboolean         is_offscreen,
                                                GError         **error);
 
 void          _clutter_backend_add_options    (ClutterBackend  *backend,
@@ -255,6 +254,8 @@ void _clutter_actor_set_enable_paint_unmapped (ClutterActor *self,
 
 void _clutter_run_repaint_functions (void);
 
+gint32 _clutter_backend_get_units_serial (ClutterBackend *backend);
+
 G_END_DECLS
 
 #endif /* _HAVE_CLUTTER_PRIVATE_H */
