@@ -86,8 +86,8 @@
  *   "angle-end"   : 360.0,
  *   "axis"        : "z-axis",
  *   "alpha"       : {
- *     "timeline" : { "duration" : 4000, "fps" : 60, "loop" : true },
- *     "function" : "sine"
+ *     "timeline" : { "duration" : 4000, "loop" : true },
+ *     "mode"     : "easeInSine"
  *   }
  * }
  * ]|
@@ -105,13 +105,35 @@
  * ]|
  *
  * A #ClutterAlpha belonging to a #ClutterBehaviour can only be defined
- * implicitely. A #ClutterTimeline belonging to a #ClutterAlpha can be
- * either defined implicitely or explicitely. Implicitely defined
- * #ClutterAlpha<!-- -->s and #ClutterTimeline<!-- -->s can omit the
- * <varname>id</varname> member, as well as the <varname>type</varname> member,
- * but will not be available using clutter_script_get_object() (they can,
- * however, be extracted using the #ClutterBehaviour and #ClutterAlpha
- * API respectively).
+ * implicitly like in the example above, or explicitly by setting the
+ * "alpha" property to point to a previously defined #ClutterAlpha, e.g.:
+ *
+ * |[
+ * {
+ *   "id"          : "rotate-behaviour",
+ *   "type"        : "ClutterBehaviourRotate",
+ *   "angle-start" : 0.0,
+ *   "angle-end"   : 360.0,
+ *   "axis"        : "z-axis",
+ *   "alpha"       : {
+ *     "id"       : "rotate-alpha",
+ *     "type"     : "ClutterAlpha",
+ *     "timeline" : {
+ *       "id"       : "rotate-timeline",
+ *       "type      : "ClutterTimeline",
+ *       "duration" : 4000,
+ *       "loop"     : true
+ *     },
+ *     "function" : "custom_sine_alpha"
+ *   }
+ * }
+ * ]|
+ *
+ * Implicitely defined #ClutterAlpha<!-- -->s and #ClutterTimeline<!-- -->s
+ * can omit the <varname>id</varname> member, as well as the
+ * <varname>type</varname> member, but will not be available using
+ * clutter_script_get_object() (they can, however, be extracted using the
+ * #ClutterBehaviour and #ClutterAlpha API respectively).
  *
  * Signal handlers can be defined inside a Clutter UI definition file and
  * then autoconnected to their respective signals using the
@@ -281,11 +303,7 @@ get_id_from_node (JsonNode *node)
     case JSON_NODE_OBJECT:
       object = json_node_get_object (node);
       if (json_object_has_member (object, "id"))
-        {
-          JsonNode *id = json_object_get_member (object, "id");
-
-          return json_node_get_string (id);
-        }
+        return json_object_get_string_member (object, "id");
       break;
 
     case JSON_NODE_VALUE:
@@ -372,11 +390,8 @@ parse_signals (ClutterScript *script,
         }
       else
         {
-          val = json_object_get_member (object, "name");
-          if ((JSON_NODE_TYPE (val) == JSON_NODE_VALUE) &&
-              json_node_get_string (val) != NULL)
-            name = json_node_get_string (val);
-          else
+          name = json_object_get_string_member (object, "name");
+          if (!name)
             {
               warn_invalid_value (script, "name", "string", val);
               continue;
@@ -391,11 +406,8 @@ parse_signals (ClutterScript *script,
         }
       else
         {
-          val = json_object_get_member (object, "handler");
-          if ((JSON_NODE_TYPE (val) == JSON_NODE_VALUE) &&
-              json_node_get_string (val) != NULL)
-            handler = json_node_get_string (val);
-          else
+          handler = json_object_get_string_member (object, "handler");
+          if (!handler)
             {
               warn_invalid_value (script, "handler", "string", val);
               continue;
@@ -404,30 +416,21 @@ parse_signals (ClutterScript *script,
 
       /* optional: "object" */
       if (json_object_has_member (object, "object"))
-        {
-          val = json_object_get_member (object, "object");
-          if ((JSON_NODE_TYPE (val) == JSON_NODE_VALUE) &&
-              json_node_get_string (val) != NULL)
-            connect = json_node_get_string (val);
-          else
-            connect = NULL;
-        }
+        connect = json_object_get_string_member (object, "object");
       else
         connect = NULL;
 
       /* optional: "after" */
       if (json_object_has_member (object, "after"))
         {
-          val = json_object_get_member (object, "after");
-          if (json_node_get_boolean (val))
+          if (json_object_get_boolean_member (object, "after"))
             flags |= G_CONNECT_AFTER;
         }
 
       /* optional: "swapped" */
       if (json_object_has_member (object, "swapped"))
         {
-          val = json_object_get_member (object, "swapped");
-          if (json_node_get_boolean (val))
+          if (json_object_get_boolean_member (object, "swapped"))
             flags |= G_CONNECT_SWAPPED;
         }
 
@@ -561,11 +564,17 @@ static const struct
 
 static const gint n_animation_modes = G_N_ELEMENTS (animation_modes);
 
-static ClutterAnimationMode
-resolve_animation_mode (const gchar *name)
+gulong
+clutter_script_resolve_animation_mode (const gchar *name)
 {
   gint i, res = 0;
 
+  /* XXX - we might be able to optimize by changing the ordering
+   * of the animation_modes array, e.g.
+   *  - special casing linear
+   *  - tokenizing ('ease', 'In', 'Sine') and matching on token
+   *  - binary searching?
+   */
   for (i = 0; i < n_animation_modes; i++)
     {
       if (strcmp (animation_modes[i].name, name) == 0)
@@ -639,7 +648,7 @@ clutter_script_parse_alpha (ClutterScript *script,
 
   val = json_object_get_member (object, "mode");
   if (val && json_node_get_string (val) != NULL)
-    mode = resolve_animation_mode (json_node_get_string (val));
+    mode = clutter_script_resolve_animation_mode (json_node_get_string (val));
 
   if (mode == CLUTTER_CUSTOM_MODE)
     {
@@ -764,8 +773,8 @@ json_object_end (JsonParser *parser,
   if (strcmp (oinfo->class_name, "ClutterStage") == 0 &&
       json_object_has_member (object, "is-default"))
     {
-      val = json_object_get_member (object, "is-default");
-      oinfo->is_stage_default = json_node_get_boolean (val);
+      oinfo->is_stage_default =
+        json_object_get_boolean_member (object, "is-default");
 
       json_object_remove_member (object, "is-default");
     }
@@ -984,7 +993,7 @@ clutter_script_parse_node (ClutterScript *script,
       switch (G_TYPE_FUNDAMENTAL (G_VALUE_TYPE (value)))
         {
         /* fundamental JSON types */
-        case G_TYPE_INT:
+        case G_TYPE_INT64:
         case G_TYPE_DOUBLE:
         case G_TYPE_STRING:
         case G_TYPE_BOOLEAN:
@@ -992,18 +1001,23 @@ clutter_script_parse_node (ClutterScript *script,
           retval = TRUE;
           break;
 
+        case G_TYPE_INT:
+          g_value_set_int (value, g_value_get_int64 (&node_value));
+          retval = TRUE;
+          break;
+
         case G_TYPE_UINT:
-          g_value_set_uint (value, (guint) g_value_get_int (&node_value));
+          g_value_set_uint (value, (guint) g_value_get_int64 (&node_value));
           retval = TRUE;
           break;
 
         case G_TYPE_ULONG:
-          g_value_set_ulong (value, (gulong) g_value_get_int (&node_value));
+          g_value_set_ulong (value, (gulong) g_value_get_int64 (&node_value));
           retval = TRUE;
           break;
 
         case G_TYPE_UCHAR:
-          g_value_set_uchar (value, (guchar) g_value_get_int (&node_value));
+          g_value_set_uchar (value, (guchar) g_value_get_int64 (&node_value));
           retval = TRUE;
           break;
 
@@ -1021,9 +1035,9 @@ clutter_script_parse_node (ClutterScript *script,
           break;
 
         case G_TYPE_ENUM:
-          if (G_VALUE_HOLDS (&node_value, G_TYPE_INT))
+          if (G_VALUE_HOLDS (&node_value, G_TYPE_INT64))
             {
-              g_value_set_enum (value, g_value_get_int (&node_value));
+              g_value_set_enum (value, g_value_get_int64 (&node_value));
               retval = TRUE;
             }
           else if (G_VALUE_HOLDS (&node_value, G_TYPE_STRING))
@@ -1039,9 +1053,9 @@ clutter_script_parse_node (ClutterScript *script,
           break;
 
         case G_TYPE_FLAGS:
-          if (G_VALUE_HOLDS (&node_value, G_TYPE_INT))
+          if (G_VALUE_HOLDS (&node_value, G_TYPE_INT64))
             {
-              g_value_set_flags (value, g_value_get_int (&node_value));
+              g_value_set_flags (value, g_value_get_int64 (&node_value));
               retval = TRUE;
             }
           else if (G_VALUE_HOLDS (&node_value, G_TYPE_STRING))
@@ -1117,21 +1131,25 @@ clutter_script_parse_node (ClutterScript *script,
                   g_free (path);
                 }
             }
-          else
+#endif
+
+          if (G_VALUE_HOLDS (&node_value, G_TYPE_STRING))
             {
-              if (G_VALUE_HOLDS (&node_value, G_TYPE_STRING))
+              const gchar *str = g_value_get_string (&node_value);
+              GObject *object = clutter_script_get_object (script, str);
+              if (object)
                 {
-                  const gchar *str = g_value_get_string (&node_value);
-                  GObject *object = clutter_script_get_object (script, str);
-                  if (object)
-                    {
-                      g_value_set_object (value, object);
-                      retval = TRUE;
-                    }
+                  CLUTTER_NOTE (SCRIPT,
+                                "Assigning '%s' (%s) to property '%s'",
+                                str,
+                                G_OBJECT_TYPE_NAME (object),
+                                name);
+
+                  g_value_set_object (value, object);
+                  retval = TRUE;
                 }
             }
           break;
-#endif
 
         default:
           retval = FALSE;
@@ -1193,6 +1211,7 @@ clutter_script_translate_parameters (ClutterScript  *script,
 
       if (!res)
         {
+          CLUTTER_NOTE (SCRIPT, "Property '%s' ignored", pinfo->name);
           unparsed = g_list_prepend (unparsed, pinfo);
           continue;
         }
