@@ -16,9 +16,9 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
- *
- *
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -28,19 +28,12 @@
 #include "cogl-context.h"
 #include "cogl-gles2-wrapper.h"
 
-#define COGL_FEATURE_BEGIN(a, b, c, d, e, f)
-#define COGL_FEATURE_FUNCTION(ret, name, args) \
-  _context->drv.pf_ ## name = NULL;
-#define COGL_FEATURE_END()
-
 void
-_cogl_create_context_driver (CoglContext *_context)
+_cogl_create_context_driver (CoglContext *context)
 {
-  #include "cogl-feature-functions.h"
-
   /* Init the GLES2 wrapper */
 #ifdef HAVE_COGL_GLES2
-  _cogl_gles2_wrapper_init (&_context->drv.gles2);
+  cogl_gles2_wrapper_init (&context->drv.gles2);
 #endif
 }
 
