@@ -50,7 +50,7 @@ static void clutter_stage_window_iface_init (ClutterStageWindowIface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (ClutterStageX11,
                          clutter_stage_x11,
-                         CLUTTER_TYPE_GROUP,
+                         G_TYPE_OBJECT,
                          G_IMPLEMENT_INTERFACE (CLUTTER_TYPE_STAGE_WINDOW,
                                                 clutter_stage_window_iface_init));
 
@@ -91,28 +91,33 @@ clutter_stage_x11_fix_window_size (ClutterStageX11 *stage_x11,
                                    gint             new_width,
                                    gint             new_height)
 {
+  ClutterBackend *backend = clutter_get_default_backend ();
+  ClutterBackendX11 *backend_x11;
   gboolean resize;
 
+  g_return_if_fail (CLUTTER_IS_BACKEND_X11 (backend));
+  backend_x11 = CLUTTER_BACKEND_X11 (backend);
+
   resize = clutter_stage_get_user_resizable (stage_x11->wrapper);
 
-  if (stage_x11->xwin != None && stage_x11->is_foreign_xwin == FALSE)
+  if (stage_x11->xwin != None && !stage_x11->is_foreign_xwin)
     {
+      gint min_width, min_height;
+      ClutterGeometry min_size;
       XSizeHints *size_hints;
-      gfloat min_width, min_height;
 
       size_hints = XAllocSizeHints();
 
+      _clutter_stage_window_get_geometry (CLUTTER_STAGE_WINDOW (stage_x11),
+                                          &min_size);
+
       if (new_width < 0)
-        clutter_actor_get_preferred_width (CLUTTER_ACTOR (stage_x11),
-                                           -1,
-                                           &min_width, NULL);
+        min_width = min_size.width;
       else
         min_width = new_width;
 
       if (new_height < 0)
-        clutter_actor_get_preferred_height (CLUTTER_ACTOR (stage_x11),
-                                            min_width,
-                                            &min_height, NULL);
+        min_height = min_size.height;
       else
         min_height = new_height;
 
@@ -122,8 +127,8 @@ clutter_stage_x11_fix_window_size (ClutterStageX11 *stage_x11,
          restrictions on the window size */
       if (!stage_x11->fullscreen_on_map)
         {
-          size_hints->min_width = (int) min_width;
-          size_hints->min_height = (int) min_height;
+          size_hints->min_width = min_width;
+          size_hints->min_height = min_height;
           size_hints->flags = PMinSize;
 
           if (!resize)
@@ -134,7 +139,7 @@ clutter_stage_x11_fix_window_size (ClutterStageX11 *stage_x11,
             }
         }
 
-      XSetWMNormalHints (stage_x11->xdpy, stage_x11->xwin, size_hints);
+      XSetWMNormalHints (backend_x11->xdpy, stage_x11->xwin, size_hints);
 
       XFree(size_hints);
     }
@@ -143,25 +148,32 @@ clutter_stage_x11_fix_window_size (ClutterStageX11 *stage_x11,
 void
 clutter_stage_x11_set_wm_protocols (ClutterStageX11 *stage_x11)
 {
-  ClutterBackendX11 *backend_x11 = stage_x11->backend;
+  ClutterBackend *backend = clutter_get_default_backend ();
+  ClutterBackendX11 *backend_x11;
   Atom protocols[2];
   int n = 0;
   
+  g_return_if_fail (CLUTTER_IS_BACKEND_X11 (backend));
+  backend_x11 = CLUTTER_BACKEND_X11 (backend);
+
   protocols[n++] = backend_x11->atom_WM_DELETE_WINDOW;
   protocols[n++] = backend_x11->atom_NET_WM_PING;
 
-  XSetWMProtocols (stage_x11->xdpy, stage_x11->xwin, protocols, n);
+  XSetWMProtocols (backend_x11->xdpy, stage_x11->xwin, protocols, n);
 }
 
 static void
-clutter_stage_x11_get_preferred_width (ClutterActor *self,
-                                       gfloat        for_height,
-                                       gfloat       *min_width_p,
-                                       gfloat       *natural_width_p)
+clutter_stage_x11_get_geometry (ClutterStageWindow *stage_window,
+                                ClutterGeometry    *geometry)
 {
-  ClutterStageX11 *stage_x11 = CLUTTER_STAGE_X11 (self);
+  ClutterBackend *backend = clutter_get_default_backend ();
+  ClutterBackendX11 *backend_x11;
+  ClutterStageX11 *stage_x11 = CLUTTER_STAGE_X11 (stage_window);
   gboolean is_fullscreen, resize;
 
+  g_return_if_fail (CLUTTER_IS_BACKEND_X11 (backend));
+  backend_x11 = CLUTTER_BACKEND_X11 (backend);
+
   is_fullscreen = FALSE;
   g_object_get (G_OBJECT (stage_x11->wrapper),
                 "fullscreen-set", &is_fullscreen,
@@ -169,110 +181,61 @@ clutter_stage_x11_get_preferred_width (ClutterActor *self,
 
   if (is_fullscreen || stage_x11->fullscreen_on_map)
     {
-      int width;
-
-      width = DisplayWidth (stage_x11->xdpy, stage_x11->xscreen);
-
-      if (min_width_p)
-        *min_width_p = width;
-
-      if (natural_width_p)
-        *natural_width_p = width;
+      geometry->width = DisplayWidth (backend_x11->xdpy, backend_x11->xscreen_num);
+      geometry->height = DisplayHeight (backend_x11->xdpy, backend_x11->xscreen_num);
 
       return;
     }
 
   resize = clutter_stage_get_user_resizable (stage_x11->wrapper);
 
-  if (min_width_p)
+  if (resize)
     {
-      if (resize)
-        *min_width_p = 1; /* FIXME need API to set this */
-      else
-        *min_width_p = stage_x11->xwin_width;
+      /* FIXME need API to set this */
+      geometry->width = 1;
+      geometry->height = 1;
+    }
+  else
+    {
+      geometry->width = stage_x11->xwin_width;
+      geometry->height = stage_x11->xwin_height;
     }
-
-  if (natural_width_p)
-    *natural_width_p = stage_x11->xwin_width;
 }
 
 static void
-clutter_stage_x11_get_preferred_height (ClutterActor *self,
-                                        gfloat        for_width,
-                                        gfloat       *min_height_p,
-                                        gfloat       *natural_height_p)
+clutter_stage_x11_resize (ClutterStageWindow *stage_window,
+                          gint                width,
+                          gint                height)
 {
-  ClutterStageX11 *stage_x11 = CLUTTER_STAGE_X11 (self);
-  gboolean is_fullscreen, resize;
-
-  is_fullscreen = FALSE;
-  g_object_get (G_OBJECT (stage_x11->wrapper),
-                "fullscreen-set", &is_fullscreen,
-                NULL);
-
-  if (is_fullscreen || stage_x11->fullscreen_on_map)
-    {
-      int height;
-
-      height = DisplayHeight (stage_x11->xdpy, stage_x11->xscreen);
-
-      if (min_height_p)
-        *min_height_p = height;
-
-      if (natural_height_p)
-        *natural_height_p = height;
-
-      return;
-    }
+  ClutterBackend *backend = clutter_get_default_backend ();
+  ClutterBackendX11 *backend_x11;
+  ClutterStageX11 *stage_x11 = CLUTTER_STAGE_X11 (stage_window);
+  gboolean resize;
 
   resize = clutter_stage_get_user_resizable (stage_x11->wrapper);
 
-  if (min_height_p)
-    {
-      if (resize)
-        *min_height_p = 1; /* FIXME need API to set this */
-      else
-        *min_height_p = stage_x11->xwin_height;
-    }
+  g_return_if_fail (CLUTTER_IS_BACKEND_X11 (backend));
+  backend_x11 = CLUTTER_BACKEND_X11 (backend);
 
-  if (natural_height_p)
-    *natural_height_p = stage_x11->xwin_height;
-}
-
-static void
-clutter_stage_x11_allocate (ClutterActor           *self,
-                            const ClutterActorBox  *box,
-                            ClutterAllocationFlags  flags)
-{
-  ClutterStageX11 *stage_x11 = CLUTTER_STAGE_X11 (self);
-  ClutterActorClass *parent_class;
-  gint new_width, new_height;
-
-  new_width  = ABS ((int) (box->x2 - box->x1));
-  new_height = ABS ((int) (box->y2 - box->y1));
-
-  if (new_width == 0 || new_height == 0)
+  if (width == 0 || height == 0)
     {
       /* Should not happen, if this turns up we need to debug it and
        * determine the cleanest way to fix.
        */
       g_warning ("X11 stage not allowed to have 0 width or height");
-      new_width = 1;
-      new_height = 1;
+      width = 1;
+      height = 1;
     }
 
-  CLUTTER_NOTE (BACKEND, "New allocation received: (%d, %d)",
-                new_width,
-                new_height);
+  CLUTTER_NOTE (BACKEND, "New size received: (%d, %d)", width, height);
 
-  if (new_width != stage_x11->xwin_width ||
-      new_height != stage_x11->xwin_height)
+  if (width != stage_x11->xwin_width ||
+      height != stage_x11->xwin_height)
     {
-      stage_x11->xwin_width  = new_width;
-      stage_x11->xwin_height = new_height;
+      stage_x11->xwin_width  = width;
+      stage_x11->xwin_height = height;
 
-      if (stage_x11->xwin != None &&
-	  !stage_x11->is_foreign_xwin)
+      if (stage_x11->xwin != None && !stage_x11->is_foreign_xwin)
         {
           CLUTTER_NOTE (BACKEND, "%s: XResizeWindow[%x] (%d, %d)",
                         G_STRLOC,
@@ -283,49 +246,69 @@ clutter_stage_x11_allocate (ClutterActor           *self,
           CLUTTER_SET_PRIVATE_FLAGS (stage_x11->wrapper,
                                      CLUTTER_STAGE_IN_RESIZE);
 
-          XResizeWindow (stage_x11->xdpy,
+          XResizeWindow (backend_x11->xdpy,
                          stage_x11->xwin,
                          stage_x11->xwin_width,
                          stage_x11->xwin_height);
         }
 
-      clutter_stage_x11_fix_window_size (stage_x11, new_width, new_height);
-
-      if (stage_x11->xpixmap != None)
-        {
-          /* Need to recreate to resize */
-          _clutter_actor_rerealize (self, NULL, NULL);
-        }
+      if (!resize)
+        clutter_stage_x11_fix_window_size (stage_x11, width, height);
     }
+}
 
-  /* chain up to fill in actor->priv->allocation */
-  parent_class = CLUTTER_ACTOR_CLASS (clutter_stage_x11_parent_class);
-  parent_class->allocate (self, box, flags);
+static inline void
+set_wm_pid (ClutterStageX11 *stage_x11)
+{
+  ClutterBackend *backend = clutter_get_default_backend ();
+  ClutterBackendX11 *backend_x11 = CLUTTER_BACKEND_X11 (backend);
+  long pid;
+
+  if (stage_x11->xwin == None)
+    return;
+
+  /* this will take care of WM_CLIENT_MACHINE and WM_LOCALE_NAME */
+  XSetWMProperties (backend_x11->xdpy, stage_x11->xwin,
+                    NULL,
+                    NULL,
+                    NULL, 0,
+                    NULL, NULL, NULL);
+
+  pid = getpid();
+  XChangeProperty (backend_x11->xdpy,
+                   stage_x11->xwin,
+                   backend_x11->atom_NET_WM_PID, XA_CARDINAL, 32,
+                   PropModeReplace,
+                   (guchar *) &pid, 1);
 }
 
 static inline void
 set_wm_title (ClutterStageX11 *stage_x11)
 {
-  ClutterBackendX11 *backend_x11 = stage_x11->backend;
+  ClutterBackend *backend = clutter_get_default_backend ();
+  ClutterBackendX11 *backend_x11;
+
+  g_return_if_fail (CLUTTER_IS_BACKEND_X11 (backend));
+  backend_x11 = CLUTTER_BACKEND_X11 (backend);
 
   if (stage_x11->xwin == None)
     return;
 
   if (stage_x11->title == NULL)
     {
-      XDeleteProperty (stage_x11->xdpy, 
+      XDeleteProperty (backend_x11->xdpy,
                        stage_x11->xwin, 
                        backend_x11->atom_NET_WM_NAME);
     }
   else
     {
-      XChangeProperty (stage_x11->xdpy, 
+      XChangeProperty (backend_x11->xdpy,
                        stage_x11->xwin, 
-                       backend_x11->atom_NET_WM_NAME, 
-                       backend_x11->atom_UTF8_STRING, 
+                       backend_x11->atom_NET_WM_NAME,
+                       backend_x11->atom_UTF8_STRING,
                        8, 
                        PropModeReplace, 
-                       (unsigned char *) stage_x11->title, 
+                       (unsigned char *) stage_x11->title,
                        (int) strlen (stage_x11->title));
     }
 }
@@ -333,6 +316,12 @@ set_wm_title (ClutterStageX11 *stage_x11)
 static inline void
 set_cursor_visible (ClutterStageX11 *stage_x11)
 {
+  ClutterBackend *backend = clutter_get_default_backend ();
+  ClutterBackendX11 *backend_x11;
+
+  g_return_if_fail (CLUTTER_IS_BACKEND_X11 (backend));
+  backend_x11 = CLUTTER_BACKEND_X11 (backend);
+
   if (stage_x11->xwin == None)
     return;
 
@@ -343,9 +332,9 @@ set_cursor_visible (ClutterStageX11 *stage_x11)
   if (stage_x11->is_cursor_visible)
     {
 #if 0 /* HAVE_XFIXES - seems buggy/unreliable */
-      XFixesShowCursor (stage_x11->xdpy, stage_x11->xwin);
+      XFixesShowCursor (backend_x11->xdpy, stage_x11->xwin);
 #else
-      XUndefineCursor (stage_x11->xdpy, stage_x11->xwin);
+      XUndefineCursor (backend_x11->xdpy, stage_x11->xwin);
 #endif /* HAVE_XFIXES */
     }
   else
@@ -353,41 +342,48 @@ set_cursor_visible (ClutterStageX11 *stage_x11)
 #if 0 /* HAVE_XFIXES - seems buggy/unreliable, check cursor in firefox 
        *               loading page after hiding.  
       */
-      XFixesHideCursor (stage_x11->xdpy, stage_x11->xwin);
+      XFixesHideCursor (backend_x11->xdpy, stage_x11->xwin);
 #else
       XColor col;
       Pixmap pix;
       Cursor curs;
 
-      pix = XCreatePixmap (stage_x11->xdpy, stage_x11->xwin, 1, 1, 1);
+      pix = XCreatePixmap (backend_x11->xdpy, stage_x11->xwin, 1, 1, 1);
       memset (&col, 0, sizeof (col));
-      curs = XCreatePixmapCursor (stage_x11->xdpy, 
+      curs = XCreatePixmapCursor (backend_x11->xdpy,
                                   pix, pix,
                                   &col, &col,
                                   1, 1);
-      XFreePixmap (stage_x11->xdpy, pix);
-      XDefineCursor (stage_x11->xdpy, stage_x11->xwin, curs);
+      XFreePixmap (backend_x11->xdpy, pix);
+      XDefineCursor (backend_x11->xdpy, stage_x11->xwin, curs);
 #endif /* HAVE_XFIXES */
     }
 }
 
-static void
-clutter_stage_x11_realize (ClutterActor *actor)
+static gboolean
+clutter_stage_x11_realize (ClutterStageWindow *stage_window)
 {
-  ClutterStageX11 *stage_x11 = CLUTTER_STAGE_X11 (actor);
+  ClutterStageX11 *stage_x11 = CLUTTER_STAGE_X11 (stage_window);
 
+  set_wm_pid (stage_x11);
   set_wm_title (stage_x11);
   set_cursor_visible (stage_x11);
+
+  return TRUE;
 }
 
 static void
 clutter_stage_x11_set_fullscreen (ClutterStageWindow *stage_window,
                                   gboolean            is_fullscreen)
 {
+  ClutterBackend *backend = clutter_get_default_backend ();
+  ClutterBackendX11 *backend_x11;
   ClutterStageX11 *stage_x11 = CLUTTER_STAGE_X11 (stage_window);
-  ClutterBackendX11 *backend_x11 = stage_x11->backend;
   ClutterStage *stage = stage_x11->wrapper;
 
+  g_return_if_fail (CLUTTER_IS_BACKEND_X11 (backend));
+  backend_x11 = CLUTTER_BACKEND_X11 (backend);
+
   if (stage == NULL)
     return;
 
@@ -402,8 +398,8 @@ clutter_stage_x11_set_fullscreen (ClutterStageWindow *stage_window,
          but Metacity (at least) will fullscreen to only one of the
          displays. This will cause the actor to report the wrong size
          until the ConfigureNotify for the correct size is received */
-      width  = DisplayWidth (stage_x11->xdpy, stage_x11->xscreen);
-      height = DisplayHeight (stage_x11->xdpy, stage_x11->xscreen);
+      width  = DisplayWidth (backend_x11->xdpy, backend_x11->xscreen_num);
+      height = DisplayHeight (backend_x11->xdpy, backend_x11->xscreen_num);
 
       /* we force the stage to the screen size here, in order to
        * get the fullscreen stage size right after the call to
@@ -427,7 +423,7 @@ clutter_stage_x11_set_fullscreen (ClutterStageWindow *stage_window,
           if (!CLUTTER_ACTOR_IS_MAPPED (stage_x11))
             {
               /* FIXME: This wont work if we support more states */
-              XChangeProperty (stage_x11->xdpy,
+              XChangeProperty (backend_x11->xdpy,
                                stage_x11->xwin,
                                backend_x11->atom_NET_WM_STATE, XA_ATOM, 32,
                                PropModeReplace,
@@ -457,7 +453,7 @@ clutter_stage_x11_set_fullscreen (ClutterStageWindow *stage_window,
           if (!CLUTTER_ACTOR_IS_MAPPED (stage_x11))
             {
               /* FIXME: This wont work if we support more states */
-              XDeleteProperty (stage_x11->xdpy, 
+              XDeleteProperty (backend_x11->xdpy,
                                stage_x11->xwin, 
                                backend_x11->atom_NET_WM_STATE);
             }
@@ -512,15 +508,20 @@ clutter_stage_x11_set_user_resizable (ClutterStageWindow *stage_window,
 static void
 update_wm_hints (ClutterStageX11 *stage_x11)
 {
+  ClutterBackend *backend = clutter_get_default_backend ();
+  ClutterBackendX11 *backend_x11;
   XWMHints wm_hints;
 
+  g_return_if_fail (CLUTTER_IS_BACKEND_X11 (backend));
+  backend_x11 = CLUTTER_BACKEND_X11 (backend);
+
   if (stage_x11->wm_state & STAGE_X11_WITHDRAWN)
     return;
 
   wm_hints.flags = StateHint;
   wm_hints.initial_state = NormalState;
 
-  XSetWMHints (stage_x11->xdpy, stage_x11->xwin, &wm_hints);
+  XSetWMHints (backend_x11->xdpy, stage_x11->xwin, &wm_hints);
 }
 
 static void
@@ -546,15 +547,20 @@ static void
 clutter_stage_x11_show (ClutterStageWindow *stage_window,
                         gboolean            do_raise)
 {
+  ClutterBackend *backend = clutter_get_default_backend ();
+  ClutterBackendX11 *backend_x11;
   ClutterStageX11 *stage_x11 = CLUTTER_STAGE_X11 (stage_window);
 
+  g_return_if_fail (CLUTTER_IS_BACKEND_X11 (backend));
+  backend_x11 = CLUTTER_BACKEND_X11 (backend);
+
   if (stage_x11->xwin != None)
     {
       if (do_raise)
         {
           CLUTTER_NOTE (BACKEND, "Raising stage[%lu]",
                         (unsigned long) stage_x11->xwin);
-          XRaiseWindow (stage_x11->xdpy, stage_x11->xwin);
+          XRaiseWindow (backend_x11->xdpy, stage_x11->xwin);
         }
 
       if (!STAGE_X11_IS_MAPPED (stage_x11))
@@ -574,20 +580,22 @@ clutter_stage_x11_show (ClutterStageWindow *stage_window,
 
       g_assert (STAGE_X11_IS_MAPPED (stage_x11));
 
-      XMapWindow (stage_x11->xdpy, stage_x11->xwin);
-
-      clutter_actor_map (CLUTTER_ACTOR (stage_x11));
       clutter_actor_map (CLUTTER_ACTOR (stage_x11->wrapper));
 
-      clutter_actor_queue_relayout (CLUTTER_ACTOR (stage_x11->wrapper));
+      XMapWindow (backend_x11->xdpy, stage_x11->xwin);
     }
 }
 
 static void
 clutter_stage_x11_hide (ClutterStageWindow *stage_window)
 {
+  ClutterBackend *backend = clutter_get_default_backend ();
+  ClutterBackendX11 *backend_x11;
   ClutterStageX11 *stage_x11 = CLUTTER_STAGE_X11 (stage_window);
 
+  g_return_if_fail (CLUTTER_IS_BACKEND_X11 (backend));
+  backend_x11 = CLUTTER_BACKEND_X11 (backend);
+
   if (stage_x11->xwin != None)
     {
       if (STAGE_X11_IS_MAPPED (stage_x11))
@@ -595,10 +603,9 @@ clutter_stage_x11_hide (ClutterStageWindow *stage_window)
 
       g_assert (!STAGE_X11_IS_MAPPED (stage_x11));
 
-      clutter_actor_unmap (CLUTTER_ACTOR (stage_x11));
       clutter_actor_unmap (CLUTTER_ACTOR (stage_x11->wrapper));
 
-      XWithdrawWindow (stage_x11->xdpy,
+      XWithdrawWindow (backend_x11->xdpy,
                        stage_x11->xwin,
                        0);
     }
@@ -630,29 +637,17 @@ static void
 clutter_stage_x11_class_init (ClutterStageX11Class *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
-  ClutterActorClass *actor_class = CLUTTER_ACTOR_CLASS (klass);
 
   gobject_class->finalize = clutter_stage_x11_finalize;
   gobject_class->dispose = clutter_stage_x11_dispose;
-
-  actor_class->realize = clutter_stage_x11_realize;
-
-  actor_class->get_preferred_width = clutter_stage_x11_get_preferred_width;
-  actor_class->get_preferred_height = clutter_stage_x11_get_preferred_height;
-  actor_class->allocate = clutter_stage_x11_allocate;
 }
 
 static void
 clutter_stage_x11_init (ClutterStageX11 *stage)
 {
-  stage->xdpy = NULL;
-  stage->xwin_root = None;
-  stage->xscreen = 0;
-
   stage->xwin = None;
   stage->xwin_width = 640;
   stage->xwin_height = 480;
-  stage->xvisinfo = None;
 
   stage->wm_state = STAGE_X11_WITHDRAWN;
 
@@ -677,13 +672,16 @@ clutter_stage_window_iface_init (ClutterStageWindowIface *iface)
   iface->set_user_resizable = clutter_stage_x11_set_user_resizable;
   iface->show = clutter_stage_x11_show;
   iface->hide = clutter_stage_x11_hide;
+  iface->resize = clutter_stage_x11_resize;
+  iface->get_geometry = clutter_stage_x11_get_geometry;
+  iface->realize = clutter_stage_x11_realize;
 }
 
 /**
  * clutter_x11_get_stage_window:
  * @stage: a #ClutterStage
  *
- * Gets the stages X Window. 
+ * Gets the stages X Window.
  *
  * Return value: An XID for the stage window.
  *
@@ -741,43 +739,36 @@ clutter_x11_get_stage_from_window (Window win)
  * clutter_x11_get_stage_visual:
  * @stage: a #ClutterStage
  *
- * Returns the stage XVisualInfo
+ * Returns an XVisualInfo suitable for creating a foreign window for the given
+ * stage. NOTE: It doesn't do as the name may suggest, which is return the
+ * XVisualInfo that was used to create an existing window for the given stage.
  *
- * Return value: The XVisualInfo for the stage.
+ * XXX: It might be best to deprecate this function and replace with something
+ * along the lines of clutter_backend_x11_get_foreign_visual () or perhaps
+ * clutter_stage_x11_get_foreign_visual ()
+ *
+ * Return value: An XVisualInfo suitable for creating a foreign stage.
+ *               You should free this using XFree.
  *
  * Since: 0.4
  */
 XVisualInfo *
 clutter_x11_get_stage_visual (ClutterStage *stage)
 {
-  ClutterStageWindow *impl;
-  ClutterStageX11 *stage_x11;
-  gboolean is_offscreen = FALSE;
+  ClutterBackend *backend = clutter_get_default_backend ();
+  ClutterBackendX11 *backend_x11;
 
-  g_return_val_if_fail (CLUTTER_IS_STAGE (stage), NULL);
+  g_return_val_if_fail (CLUTTER_IS_BACKEND_X11 (backend), NULL);
+  backend_x11 = CLUTTER_BACKEND_X11 (backend);
 
-  g_object_get (G_OBJECT (stage), "offscreen", &is_offscreen, NULL);
-
-  impl = _clutter_stage_get_window (stage);
-  g_assert (CLUTTER_IS_STAGE_X11 (impl));
-
-  stage_x11 = CLUTTER_STAGE_X11 (impl);
-
-  if (stage_x11->xvisinfo == NULL)
-    {
-      ClutterBackendX11 *backend_x11 = stage_x11->backend;
-
-      stage_x11->xvisinfo =
-        clutter_backend_x11_get_visual_info (backend_x11, is_offscreen);
-    }
-
-  return stage_x11->xvisinfo;
+  return clutter_backend_x11_get_visual_info (backend_x11);
 }
 
 typedef struct {
   ClutterStageX11 *stage_x11;
   ClutterGeometry geom;
   Window xwindow;
+  guint destroy_old_xwindow : 1;
 } ForeignWindowData;
 
 static void
@@ -785,8 +776,18 @@ set_foreign_window_callback (ClutterActor *actor,
                              void         *data)
 {
   ForeignWindowData *fwd = data;
+  ClutterBackend *backend = clutter_get_default_backend ();
+  ClutterBackendX11 *backend_x11 = CLUTTER_BACKEND_X11 (backend);
 
-  CLUTTER_NOTE (BACKEND, "Setting foreign window (0x%x)", (int) fwd->xwindow);
+  CLUTTER_NOTE (BACKEND, "Setting foreign window (0x%x)",
+                (unsigned int) fwd->xwindow);
+
+  if (fwd->destroy_old_xwindow && fwd->stage_x11->xwin != None)
+    {
+      CLUTTER_NOTE (BACKEND, "Destroying previous window (0x%x)",
+                    (unsigned int) fwd->xwindow);
+      XDestroyWindow (backend_x11->xdpy, fwd->stage_x11->xwin);
+    }
 
   fwd->stage_x11->xwin = fwd->xwindow;
   fwd->stage_x11->is_foreign_xwin = TRUE;
@@ -818,6 +819,8 @@ gboolean
 clutter_x11_set_stage_foreign (ClutterStage *stage,
                                Window        xwindow)
 {
+  ClutterBackend *backend = clutter_get_default_backend ();
+  ClutterBackendX11 *backend_x11;
   ClutterStageX11 *stage_x11;
   ClutterStageWindow *impl;
   ClutterActor *actor;
@@ -826,6 +829,10 @@ clutter_x11_set_stage_foreign (ClutterStage *stage,
   Window root_return;
   Status status;
   ForeignWindowData fwd;
+  XVisualInfo *xvisinfo;
+
+  g_return_val_if_fail (CLUTTER_IS_BACKEND_X11 (backend), FALSE);
+  backend_x11 = CLUTTER_BACKEND_X11 (backend);
 
   g_return_val_if_fail (CLUTTER_IS_STAGE (stage), FALSE);
   g_return_val_if_fail (xwindow != None, FALSE);
@@ -835,19 +842,21 @@ clutter_x11_set_stage_foreign (ClutterStage *stage,
   impl = _clutter_stage_get_window (stage);
   stage_x11 = CLUTTER_STAGE_X11 (impl);
 
+  xvisinfo = clutter_backend_x11_get_visual_info (backend_x11);
+
   clutter_x11_trap_x_errors ();
 
-  status = XGetGeometry (stage_x11->xdpy, xwindow,
+  status = XGetGeometry (backend_x11->xdpy, xwindow,
                          &root_return,
                          &x, &y,
                          &width, &height,
                          &border,
                          &depth);
-  
+
   if (clutter_x11_untrap_x_errors () ||
       !status ||
       width == 0 || height == 0 ||
-      depth != stage_x11->xvisinfo->depth)
+      depth != xvisinfo->depth)
     {
       g_warning ("Unable to retrieve the new window geometry");
       return FALSE;
@@ -855,6 +864,13 @@ clutter_x11_set_stage_foreign (ClutterStage *stage,
 
   fwd.stage_x11 = stage_x11;
   fwd.xwindow = xwindow;
+
+  /* destroy the old Window, if we have one and it's ours */
+  if (stage_x11->xwin != None && !stage_x11->is_foreign_xwin)
+    fwd.destroy_old_xwindow = TRUE;
+  else
+    fwd.destroy_old_xwindow = FALSE;
+
   fwd.geom.x = x;
   fwd.geom.y = y;
   fwd.geom.width = width;
